@@ -1,30 +1,24 @@
 check_active_dims <- function(columns, lengthscales) {
   columns <- as.integer(columns)
 
-  if (!all(columns >= 1)) {
-    msg <- cli::format_error(
+  columns_are_positive_int <- all(columns >= 1)
+  if (!columns_are_positive_int) {
+    cli::cli_abort(
       c(
         "Columns must be a vector of positive integers",
         "But we see columns as {columns}"
       )
     )
-    stop(
-      msg,
-      call. = FALSE
-    )
   }
 
-  if (length(columns) != length(lengthscales)) {
-    msg <- cli::format_error(
+  column_length_match_kernel_length <- length(columns) != length(lengthscales)
+  if (column_length_match_kernel_length) {
+    cli::cli_abort(
       c(
         "Columns has length: {.val {length(columns)}}, but the kernel has \\
          dimension: {.val {length(lengthscales)}}"
       )
     )
-    stop(
-      msg,
-      call. = FALSE
-    )
   }
 
   columns - 1L
